/*  Glimmer - windows.h
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef _WINDOWS_H_
#define _WINDOWS_H_

#ifdef __cplusplus
extern "C" {
#endif

#include "declarations.h"

void new_window_cb(GtkWidget *widget, gpointer data);
void cycle_left_cb(GtkWidget *widget, gpointer data);
void cycle_right_cb(GtkWidget *widget, gpointer data);
void move_left_cb(GtkWidget *widget, gpointer data);
void move_right_cb(GtkWidget *widget, gpointer data);

#ifdef WITH_PYTHON
void cycle_left_paned_cb(GtkWidget *widget, gpointer data);
void cycle_right_paned_cb(GtkWidget *widget, gpointer data);
void focus_current_file_cb(GtkWidget *widget, gpointer data);
void focus_current_paned_cb(GtkWidget *widget, gpointer data);
#endif

#ifdef __cplusplus
}
#endif

#endif
